package cc.fascinated.services;

import cc.fascinated.platform.Platform;
import cc.fascinated.platform.impl.ScoreSaberPlatform;
import lombok.NonNull;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.ApplicationContext;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

/**
 * @author Fascinated (fascinated7)
 */
@Service
@Log4j2(topic = "PlatformService")
public class PlatformService {
    /**
     * The loaded platforms.
     */
    private final List<Platform> platforms = new ArrayList<>();

    @Autowired
    public PlatformService(@NonNull ApplicationContext context) {
        registerPlatform(context.getBean(ScoreSaberPlatform.class));
    }

    @Scheduled(cron = "0 */1 * * * *")
    public void updatePlatforms() {
        log.info("Updating %s platforms...".formatted(this.platforms.size()));
        for (Platform platform : this.platforms) {
            platform.updatePlayers();
            platform.updateMetrics();
        }
        log.info("Finished updating platforms.");
    }

    /**
     * Registers a platform.
     *
     * @param platform the platform to register
     */
    public void registerPlatform(Platform platform) {
        this.platforms.add(platform);
    }
}

